pub struct NaverTrend { /* private fields */ }Implementations
Sourcepub fn from_client(client: Client) -> Self
pub fn from_client(client: Client) -> Self
Wraps an already-built client (e.g. from ClientBuilder).
Sourcepub async fn get(
&self,
symbol: impl Into<String>,
) -> Result<Vec<NaverTrendView>>
pub async fn get( &self, symbol: impl Into<String>, ) -> Result<Vec<NaverTrendView>>
Get Naver trend data with a daily frequency for a project that is associated with a given symbol. The values in response are normalized into a range from 0 to 100, where 0 corresponds to a minimum interest, and 100 corresponds to a maximum interest of users in Naver search engine.